==> qtjambi-designer-debuginfo-macos-5.15.20.jar: sources/QtJambiDesigner/QDesignerFormEditorPluginInterface_shell.h <==
#ifndef QDESIGNERFORMEDITORPLUGININTERFACE_IMPL_SHELL_H
#define QDESIGNERFORMEDITORPLUGININTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtDesigner/abstractformeditorplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtDesigner/abstractformeditor.h>
#include <QtWidgets/qaction.h>
#include <QtJambi/RegistryAPI>


class QDesignerFormEditorPluginInterface_shell : public QDesignerFormEditorPluginInterface, public QtJambiShellInterface
{
public:
    QDesignerFormEditorPluginInterface_shell();
    ~QDesignerFormEditorPluginInterface_shell() override;

    QAction* action() const override;
    QDesignerFormEditorInterface* core() const override;
    void initialize(QDesignerFormEditorInterface* core0) override;
    bool isInitialized() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerFormEditorPluginInterface_access : public QDesignerFormEditorPluginInterface
{
    jobject __qt_action_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_core_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_initialize_QDesignerFormEditorInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID core0);
    jboolean __qt_isInitialized_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QDESIGNERFORMEDITORPLUGININTERFACE_IMPL_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.6.3.jar: sources/QtJambiDesigner/QDesignerFormEditorPluginInterface_shell.h <==
#ifndef QDESIGNERFORMEDITORPLUGININTERFACE_IMPL_SHELL_H
#define QDESIGNERFORMEDITORPLUGININTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtDesigner/abstractformeditorplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtDesigner/abstractformeditor.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtJambi/RegistryAPI>


class QDesignerFormEditorPluginInterface_shell : public QDesignerFormEditorPluginInterface, public QtJambiShellInterface
{
public:
    QDesignerFormEditorPluginInterface_shell();
    ~QDesignerFormEditorPluginInterface_shell() override;

    QAction* action() const override;
    QDesignerFormEditorInterface* core() const override;
    void initialize(QDesignerFormEditorInterface* core0) override;
    bool isInitialized() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerFormEditorPluginInterface_access : public QDesignerFormEditorPluginInterface
{
    jobject __qt_action_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_core_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_initialize_QDesignerFormEditorInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID core0);
    jboolean __qt_isInitialized_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QDESIGNERFORMEDITORPLUGININTERFACE_IMPL_SHELL_H
